"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClientReadyState = exports.RefreshResult = exports.OverrideBehaviour = exports.User = exports.SettingKeyValue = exports.Comparator = exports.SettingType = exports.FormattableLogMessage = exports.LogLevel = exports.DataGovernance = exports.PollingMode = exports.createFlagOverridesFromMap = exports.createConsoleLogger = exports.disposeAllClients = exports.getClient = void 0;
var configcat_common_1 = require("configcat-common");
var configcatcommon = require("configcat-common");
var Cache_1 = require("./Cache");
var ConfigFetcher_1 = require("./ConfigFetcher");
var Version_1 = require("./Version");
/**
 * Returns an instance of `ConfigCatClient` for the specified SDK Key.
 * @remarks This method returns a single, shared instance per each distinct SDK Key.
 * That is, a new client object is created only when there is none available for the specified SDK Key.
 * Otherwise, the already created instance is returned (in which case the `pollingMode` and `options` arguments are ignored).
 * So, please keep in mind that when you make multiple calls to this method using the same SDK Key, you may end up with multiple references to the same client object.
 * @param sdkKey SDK Key to access the ConfigCat config.
 * @param pollingMode The polling mode to use.
 * @param options Options for the specified polling mode.
 */
function getClient(sdkKey, pollingMode, options) {
    return configcatcommon.getClient(sdkKey, pollingMode !== null && pollingMode !== void 0 ? pollingMode : configcat_common_1.PollingMode.AutoPoll, options, {
        configFetcher: new ConfigFetcher_1.HttpConfigFetcher(),
        sdkType: "ConfigCat-JS-SSR",
        sdkVersion: Version_1.default,
        defaultCacheFactory: function (options) { return new configcat_common_1.ExternalConfigCache(new Cache_1.LocalStorageCache(), options.logger); }
    });
}
exports.getClient = getClient;
/**
 * Disposes all existing `ConfigCatClient` instances.
 */
function disposeAllClients() {
    configcatcommon.disposeAllClients();
}
exports.disposeAllClients = disposeAllClients;
/**
 * Creates an instance of `ConfigCatConsoleLogger`.
 * @param logLevel Log level (the minimum level to use for filtering log events).
 */
function createConsoleLogger(logLevel) {
    return configcatcommon.createConsoleLogger(logLevel);
}
exports.createConsoleLogger = createConsoleLogger;
/**
 * Creates an instance of `FlagOverrides` that uses a map data source.
 * @param map The map that contains the overrides.
 * @param behaviour The override behaviour.
 * Specifies whether the local values should override the remote values
 * or local values should only be used when a remote value doesn't exist
 * or the local values should be used only.
 */
function createFlagOverridesFromMap(map, behaviour) {
    return new configcat_common_1.FlagOverrides(new configcat_common_1.MapOverrideDataSource(map), behaviour);
}
exports.createFlagOverridesFromMap = createFlagOverridesFromMap;
/* Public types re-export from common-js */
// These exports should be kept in sync with the exports listed in the section "Public types for end users" of common-js/src/index.ts!
var configcat_common_2 = require("configcat-common");
Object.defineProperty(exports, "PollingMode", { enumerable: true, get: function () { return configcat_common_2.PollingMode; } });
var configcat_common_3 = require("configcat-common");
Object.defineProperty(exports, "DataGovernance", { enumerable: true, get: function () { return configcat_common_3.DataGovernance; } });
var configcat_common_4 = require("configcat-common");
Object.defineProperty(exports, "LogLevel", { enumerable: true, get: function () { return configcat_common_4.LogLevel; } });
var configcat_common_5 = require("configcat-common");
Object.defineProperty(exports, "FormattableLogMessage", { enumerable: true, get: function () { return configcat_common_5.FormattableLogMessage; } });
var configcat_common_6 = require("configcat-common");
Object.defineProperty(exports, "SettingType", { enumerable: true, get: function () { return configcat_common_6.SettingType; } });
Object.defineProperty(exports, "Comparator", { enumerable: true, get: function () { return configcat_common_6.Comparator; } });
var configcat_common_7 = require("configcat-common");
Object.defineProperty(exports, "SettingKeyValue", { enumerable: true, get: function () { return configcat_common_7.SettingKeyValue; } });
var configcat_common_8 = require("configcat-common");
Object.defineProperty(exports, "User", { enumerable: true, get: function () { return configcat_common_8.User; } });
var configcat_common_9 = require("configcat-common");
Object.defineProperty(exports, "OverrideBehaviour", { enumerable: true, get: function () { return configcat_common_9.OverrideBehaviour; } });
var configcat_common_10 = require("configcat-common");
Object.defineProperty(exports, "RefreshResult", { enumerable: true, get: function () { return configcat_common_10.RefreshResult; } });
var configcat_common_11 = require("configcat-common");
Object.defineProperty(exports, "ClientReadyState", { enumerable: true, get: function () { return configcat_common_11.ClientReadyState; } });
